import { tree } from 'd3';

export const nodeLinkTree = (
  selection,
  { root, width, height }
) => {
  tree().size([width - 20, height - 50])(root);

  const colorScale = d3.scaleOrdinal(
    d3.schemeCategory10
  );

  selection
    .selectAll('line')
    .data(root.links())
    .join('line')
    .attr('x1', (d) => d.source.x)
    .attr('y1', (d) => d.source.y + 10)
    .attr('x2', (d) => d.target.x)
    .attr('y2', (d) => d.target.y + 10)
    .attr('stroke', 'black');

  const circle = selection
    .selectAll('circle')
    .data(root.descendants())
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y + 20)
    .attr('r', 10)
    .style('fill', (d) => {
      while (d.depth > 1) d = d.parent;
      return colorScale(d.data.name);
    });

  circle.append('title').text((d) => d.data.name);

  circle.on('mouseover', function (event, d) {
    const tooltip = selection
      .append('g')
      .attr('id', 'tooltip');
    const tooltipWidth = 200;
    const tooltipHeight = 20;
    const mouseX = event.clientX;
    const mouseY = event.clientY;
    const tooltipX =
      mouseX + tooltipWidth > width
        ? mouseX - tooltipWidth
        : mouseX;
    const tooltipY =
      mouseY - tooltipHeight < 0
        ? mouseY + tooltipHeight
        : mouseY - tooltipHeight;
    tooltip
      .append('rect')
      .attr('x', tooltipX)
      .attr('y', tooltipY)
      .attr('width', tooltipWidth)
      .attr('height', tooltipHeight)
      .attr('rx', 10)
      .attr('ry', 10)
      .style('fill', '#333')
      .style('opacity', 1);
    tooltip
      .append('text')
      .attr('x', tooltipX + tooltipWidth / 2)
      .attr('y', tooltipY + tooltipHeight / 2 + 5)
      .attr('text-anchor', 'middle')
      .style('font-family', 'sans-serif')

      .style('fill', '#fff')
      .text(d.data.name);
  });

  circle.on('mouseout', function (event, d) {
    selection.select('#tooltip').remove();
  });
};
