import { select, hierarchy } from 'd3';
import { nodeLinkTree } from './nodeLinkTree';

export const viz = (
  container,
  { state, setState }
) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  if (!state.data) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch('data.csv')
      .then((response) => response.text())
      .then((csvData) => {
        const parsedData = d3.csvParse(csvData);
        // group data by department and nationality
        const nestedData = parsedData.reduce((acc, d) => {
          const departmentNode = acc.find(node => node.name === d.Department);
          if (!departmentNode) {
            acc.push({
              name: d.Department,
              children: [{
                name: d.Classification,
                value: 1
              }]
            });
          } else {
            const classificationNode = departmentNode.children.find(node => node.name === d.Classification);
            if (!classificationNode) {
              departmentNode.children.push({
                name: d.Classification,
                value: 1
              });
            } else {
              classificationNode.value += 1;
            }
          }
          return acc;
        }, []);

        // convert nested data into hierarchical format
        const hierarchicalData = {
          name: 'Museum of Modern Art',
          children: nestedData
        };
          console.log(hierarchicalData)


        setState((state) => ({
          ...state,
          data: hierarchicalData,
        }));
      });
  }

  const { data } = state;
  if (data && data !== 'LOADING') {
    const root = hierarchy(data);
    svg.call(nodeLinkTree, {
      root,
      width,
      height,
    });
  }
};
